# PySABER

## Documentation
Documentation for PySABER is available at the link [https://pysaber.readthedocs.io/](https://pysaber.readthedocs.io/). 

## Introduction
PySABER is a python package for characterizing the X-ray source and detector blurs in cone-beam X-ray imaging systems. SABER is an abbreviation for systems approach to blur estimation and reduction. Once the parameters of both source and detector blurs are estimated, this package is also useful to reduce blur in radiographs using deblurring algorithms. 


## References
K. Aditya Mohan, Robert M. Panas, and Jefferson A. Cuadra. "SABER: A Systems Approach to Blur Estimation and Reduction in X-ray Imaging." arXiv preprint arXiv:1905.03935 (2019) [pdf](https://arxiv.org/pdf/1905.03935.pdf)


## License
This project is licensed under the MIT License. LLNL-CODE-766837.


## Installation and Usage
Please refer to the documentation at the link [https://pysaber.readthedocs.io/](https://pysaber.readthedocs.io/).
 

## Contributors
* [K. Aditya Mohan](https://orcid.org/0000-0002-0921-6559)
* Robert M. Panas
* Jefferson A. Cuadra


## Changelog
* May 2020: Added documentation and released version 1.0.0 with changes to improve ease of use. 
* May 2020: Moved repository from [https://github.com/sabersw/pysaber](https://github.com/sabersw/pysaber) to [https://github.com/LLNL/pysaber](https://github.com/LLNL/pysaber).
